## `detector_lookup`

The purpose of the [`detector_lookup`](../_api/soxspipe.commonutils.detector_lookup.html) utility is to act as reference in the code for the various characteristics of the soxs detectors. 

When initiated [`detector_lookup`](../_api/soxspipe.commonutils.detector_lookup.html) reads the detector characteristics from a [Detector Parameters](../files/detector_parameters.md) file and can later serve these parameters to the soxspipe code when requested.

```eval_rst
.. autoclass:: soxspipe.commonutils.detector_lookup
    :members:
```
